==> mythbuntu-common_0.26.orig.tar.gz: mythbuntu-common-0.26/setup.py <==
#!/usr/bin/python
# mythbuntu-common install script
# Copyright (C) 2007, Mario Limonciello <superm1@mythbuntu.org>
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

from distutils.core import setup

import glob, os.path

setup(
    name="mythbuntu_common",
    author="Mario Limonciello",
    author_email="superm1@mythbuntu.org",
    maintainer="Ubuntu MythTV Team",
    maintainer_email="ubuntu-mythtv@lists.ubuntu.com",
    url="http://www.mythbuntu.org",
    license="gpl",
    description="commonly used mythbuntu functions",
    packages=["mythbuntu_common"],
    data_files=[("share/mythbuntu-common/scripts", glob.glob("scripts/*")),
                ("share/mythbuntu-common/graphics", glob.glob("graphics/*")),
                ("share/mythbuntu-common/examples", glob.glob("examples/*")),
                ("share/mythbuntu-common/glade", glob.glob("glade/*"))],
    scripts=[],
)

==> mythbuntu-common_0.50.orig.tar.gz: mythbuntu-common-0.50/setup.py <==
#!/usr/bin/python
# mythbuntu-common install script
# Copyright (C) 2007-2009, Mario Limonciello <superm1@mythbuntu.org>
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

from distutils.core import setup
from DistUtilsExtra.command import *

import glob, os.path

setup(
    name="mythbuntu-common",
    author="Mario Limonciello",
    author_email="superm1@mythbuntu.org",
    maintainer="Ubuntu MythTV Team",
    maintainer_email="ubuntu-mythtv@lists.ubuntu.com",
    url="http://www.mythbuntu.org",
    license="gpl",
    description="commonly used mythbuntu functions",
    packages=['mythbuntu_common'],
    data_files=[("share/mythbuntu/examples", glob.glob("examples/*")),
                ("share/mythbuntu/plugins/python", glob.glob("plugins/python/*")),
                ("share/mythbuntu/plugins/ui", glob.glob("plugins/ui/*"))],
    scripts=[],
    cmdclass = { "build" : build_extra.build_extra,
        "build_i18n" : build_i18n.build_i18n,
        "clean" : clean_i18n.clean_i18n
        }
)
